% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-latent-models.R
\name{compare_sequence_hmms}
\alias{compare_sequence_hmms}
\title{Compare fitted sequence HMMs descriptively}
\usage{
compare_sequence_hmms(...)
}
\arguments{
\item{...}{Fitted HMM or mixture-HMM objects.}
}
\value{
A data frame containing log likelihood, AIC, BIC, parameter count,
convergence status, and delta criteria. Criteria are descriptive and do not
automatically select a substantive model.
}
\description{
Compare fitted sequence HMMs descriptively
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
model_1 <- fit_sequence_hmm(sequences, 1L, max_iter = 5L)
model_2 <- fit_sequence_hmm(sequences, 2L, max_iter = 5L)
compare_sequence_hmms(one = model_1, two = model_2)

}
