% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-inference.R
\name{plot_sequence_group_inference}
\alias{plot_sequence_group_inference}
\title{Plot sequence group inference}
\usage{
plot_sequence_group_inference(
  inference,
  type = c("permutation", "group_means"),
  ...
)
}
\arguments{
\item{inference}{A sequence group-inference object.}

\item{type}{\code{"permutation"} or \code{"group_means"}.}

\item{...}{Additional base-graphics arguments.}
}
\value{
The inference object, invisibly.
}
\description{
Plot sequence group inference
}
\examples{
# See `test_sequence_group_difference()`.
}
