% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-networks.R
\name{bootstrap_transition_network}
\alias{bootstrap_transition_network}
\title{Bootstrap transition-network edge weights}
\usage{
bootstrap_transition_network(
  data,
  sequence_id_col = "sequence_id",
  order_col = "sequence_order",
  state_col = "state",
  n_boot = 100L,
  level = 0.95,
  seed = 1L,
  include_self = TRUE
)
}
\arguments{
\item{data}{Long-format sequence data.}

\item{sequence_id_col, order_col, state_col}{Sequence columns.}

\item{n_boot}{Number of bootstrap samples of whole sequences.}

\item{level}{Confidence level for percentile intervals.}

\item{seed}{Reproducibility seed.}

\item{include_self}{Include self-transitions.}
}
\value{
A data frame containing observed edge weights, bootstrap means,
standard deviations, and percentile intervals.
}
\description{
Bootstrap transition-network edge weights
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
bootstrap_transition_network(sequences, n_boot = 5L, seed = 1L)

}
