% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-inference.R
\name{summarise_sequence_group_inference}
\alias{summarise_sequence_group_inference}
\title{Summarise sequence group inference}
\usage{
summarise_sequence_group_inference(inference)
}
\arguments{
\item{inference}{A sequence group-inference object.}
}
\value{
A list containing the estimate, optional interval, design, and
interpretation statement.
}
\description{
Summarise sequence group inference
}
\examples{
# See `test_sequence_group_difference()`.
}
