% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-distances-clustering.R
\name{summarise_sequence_cluster_stability}
\alias{summarise_sequence_cluster_stability}
\title{Summarise sequence-cluster stability}
\usage{
summarise_sequence_cluster_stability(bootstrap, threshold = 0.8)
}
\arguments{
\item{bootstrap}{A result from \code{\link[=bootstrap_sequence_clusters]{bootstrap_sequence_clusters()}}.}

\item{threshold}{Pairwise stability threshold.}
}
\value{
Overall, cluster-level, and low-stability pair summaries.
}
\description{
Summarise sequence-cluster stability
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
distance <- compute_sequence_distance(sequences)
boot <- bootstrap_sequence_clusters(distance, k = 2L, n_boot = 5L)
summarise_sequence_cluster_stability(boot)

}
