% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-time-models.R
\name{plot_time_varying_sequence_model}
\alias{plot_time_varying_sequence_model}
\title{Plot predicted time-varying sequence probabilities}
\usage{
plot_time_varying_sequence_model(
  model,
  time = NULL,
  level = 0.95,
  show_interval = TRUE,
  ...
)
}
\arguments{
\item{model}{A fitted time-varying sequence model.}

\item{time}{Optional prediction grid.}

\item{level}{Pointwise confidence level.}

\item{show_interval}{Draw pointwise confidence ribbons.}

\item{...}{Additional arguments passed to \code{\link[graphics:plot]{graphics::plot()}}.}
}
\value{
Prediction data, invisibly.
}
\description{
Plot predicted time-varying sequence probabilities
}
\examples{
# See `fit_time_varying_sequence_model()`.
}
