% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-subsequences.R
\name{summarise_sequence_subsequences}
\alias{summarise_sequence_subsequences}
\title{Summarise non-contiguous subsequences}
\usage{
summarise_sequence_subsequences(occurrences)
}
\arguments{
\item{occurrences}{A result from \code{\link[=extract_sequence_subsequences]{extract_sequence_subsequences()}}.}
}
\value{
A data frame with occurrence counts, sequence prevalence, and span
diagnostics.
}
\description{
Summarise non-contiguous subsequences
}
\examples{
data <- data.frame(sequence_id = rep(c("a", "b"), each = 4L),
                   sequence_order = rep(1:4, 2L),
                   state = c("A", "B", "C", "D", "A", "C", "B", "D"))
summarise_sequence_subsequences(extract_sequence_subsequences(data))
}
