% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-multichannel-hmm.R
\name{plot_multichannel_sequence_hmm}
\alias{plot_multichannel_sequence_hmm}
\title{Plot multichannel HMM emission profiles}
\usage{
plot_multichannel_sequence_hmm(model, channel = model$channel_names[1L], ...)
}
\arguments{
\item{model}{A fitted multichannel HMM.}

\item{channel}{Channel name to plot.}

\item{...}{Additional arguments passed to \code{\link[graphics:barplot]{graphics::barplot()}}.}
}
\value{
The selected emission matrix, invisibly.
}
\description{
Plot multichannel HMM emission profiles
}
\examples{
# See `fit_multichannel_sequence_hmm()`.
}
