% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-distances-clustering.R
\name{summarise_sequence_distance}
\alias{summarise_sequence_distance}
\title{Summarise a sequence-distance object}
\usage{
summarise_sequence_distance(distance)
}
\arguments{
\item{distance}{A distance object returned by \code{\link[=compute_sequence_distance]{compute_sequence_distance()}}.}
}
\value{
A list containing an overall summary and per-sequence mean, median,
minimum, and maximum distances.
}
\description{
Summarise a sequence-distance object
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
distance <- compute_sequence_distance(sequences)
summarise_sequence_distance(distance)

}
