% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-latent-models.R
\name{summarise_sequence_hmm}
\alias{summarise_sequence_hmm}
\title{Summarise a fitted sequence HMM}
\usage{
summarise_sequence_hmm(model)
}
\arguments{
\item{model}{A single or mixture HMM.}
}
\value{
A list of convergence, fit, initial, transition, emission, and
mixture summaries.
}
\description{
Summarise a fitted sequence HMM
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
model <- fit_sequence_hmm(sequences, 2L, max_iter = 5L)
summarise_sequence_hmm(model)

}
