% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-time-models.R
\name{predict_time_varying_sequence_model}
\alias{predict_time_varying_sequence_model}
\title{Predict a time-varying sequence model}
\usage{
predict_time_varying_sequence_model(
  model,
  time = NULL,
  groups = NULL,
  level = 0.95
)
}
\arguments{
\item{model}{A fitted time-varying sequence model.}

\item{time}{Optional numeric prediction grid.}

\item{groups}{Optional subset of fitted groups.}

\item{level}{Confidence level for pointwise intervals.}
}
\value{
A data frame with fitted probabilities and pointwise intervals.
}
\description{
Predict a time-varying sequence model
}
\examples{
# See `fit_time_varying_sequence_model()`.
}
