% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-visualisations-extended.R
\name{plot_sequence_distance_heatmap}
\alias{plot_sequence_distance_heatmap}
\title{Plot a sequence-distance heatmap}
\usage{
plot_sequence_distance_heatmap(
  distance,
  order_by = NULL,
  palette = "Viridis",
  show_labels = TRUE,
  ...
)
}
\arguments{
\item{distance}{A sequence distance object or square matrix.}

\item{order_by}{Optional clustering or named assignment vector used to order
the matrix.}

\item{palette}{Base HCL palette.}

\item{show_labels}{Draw sequence identifiers.}

\item{...}{Additional arguments passed to \code{\link[graphics:image]{graphics::image()}}.}
}
\value{
The ordered distance matrix, invisibly.
}
\description{
Plot a sequence-distance heatmap
}
\examples{
data <- data.frame(sequence_id = rep(paste0("s", 1:4), each = 4L),
                   sequence_order = rep(1:4, 4L),
                   state = c("A", "B", "C", "D", "A", "B", "C", "C",
                             "D", "C", "B", "A", "D", "C", "A", "A"))
plot_sequence_distance_heatmap(compute_sequence_distance(data))
}
