% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-panel.R
\name{summarise_sequence_panel}
\alias{summarise_sequence_panel}
\title{Summarise a sequence panel}
\usage{
summarise_sequence_panel(panel)
}
\arguments{
\item{panel}{A result from \code{\link[=prepare_sequence_panel]{prepare_sequence_panel()}}.}
}
\value{
A list with occasion-level sequence summaries and state prevalence.
}
\description{
Summarise a sequence panel
}
\examples{
panel_data <- data.frame(
  participant_id = rep(c("p1", "p2"), each = 6L),
  occasion = rep(rep(c(1, 2), each = 3L), times = 2L),
  sequence_id = rep(c("a", "b", "c", "d"), each = 3L),
  sequence_order = rep(1:3, times = 4L),
  state = c("A", "B", "C", "A", "C", "C", "C", "B", "A", "C", "B", "B")
)
summarise_sequence_panel(prepare_sequence_panel(panel_data, "participant_id", "occasion"))
}
