% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-covariate-hmm.R
\name{predict_covariate_transition_probabilities}
\alias{predict_covariate_transition_probabilities}
\title{Predict covariate-dependent transition probabilities}
\usage{
predict_covariate_transition_probabilities(model, newdata)
}
\arguments{
\item{model}{A fitted covariate HMM.}

\item{newdata}{Data frame containing transition covariates.}
}
\value{
A long data frame with one row per input row, origin state, and
destination state.
}
\description{
Predict covariate-dependent transition probabilities
}
\examples{
# See `fit_covariate_sequence_hmm()`.
}
