% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-networks.R
\name{summarise_transition_centrality}
\alias{summarise_transition_centrality}
\title{Summarise transition-network centrality}
\usage{
summarise_transition_centrality(
  network,
  directed = TRUE,
  pagerank_damping = 0.85,
  pagerank_tolerance = 1e-10,
  pagerank_max_iter = 1000L
)
}
\arguments{
\item{network}{A first-order transition network.}

\item{directed}{Treat the network as directed.}

\item{pagerank_damping}{Damping factor for PageRank.}

\item{pagerank_tolerance}{Convergence tolerance.}

\item{pagerank_max_iter}{Maximum PageRank iterations.}
}
\value{
A data frame containing degree, strength, weighted closeness,
unweighted betweenness, and PageRank centrality.
}
\description{
Summarise transition-network centrality
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
network <- create_transition_network(sequences)
summarise_transition_centrality(network)

}
