% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-visualisations-extended.R
\name{plot_transition_network}
\alias{plot_transition_network}
\title{Plot a first-order transition network}
\usage{
plot_transition_network(
  network,
  weight_col = "weight",
  minimum_weight = 0,
  vertex_cex = 1,
  edge_scale = 5,
  ...
)
}
\arguments{
\item{network}{A first-order network from \code{\link[=create_transition_network]{create_transition_network()}}.}

\item{weight_col}{Edge-weight column.}

\item{minimum_weight}{Minimum plotted edge weight.}

\item{vertex_cex}{Vertex label size.}

\item{edge_scale}{Edge-width multiplier.}

\item{...}{Additional arguments passed to \code{\link[graphics:plot.window]{graphics::plot.window()}}.}
}
\value{
The plotted network rows, invisibly.
}
\description{
Plot a first-order transition network
}
\examples{
data <- data.frame(sequence_id = rep(c("a", "b"), each = 4L),
                   sequence_order = rep(1:4, 2L),
                   state = c("A", "B", "C", "D", "A", "C", "C", "D"))
plot_transition_network(create_transition_network(data, normalise = "from"))
}
