% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-distances-clustering.R
\name{validate_sequence_clusters}
\alias{validate_sequence_clusters}
\title{Validate sequence clusters descriptively}
\usage{
validate_sequence_clusters(clustering, distance = NULL)
}
\arguments{
\item{clustering}{A result from \code{\link[=cluster_sequences]{cluster_sequences()}} or a named assignment
vector.}

\item{distance}{Optional distance object when \code{clustering} is an assignment
vector.}
}
\value{
A list containing overall validation metrics, cluster sizes, and
per-sequence silhouette values.
}
\description{
Validate sequence clusters descriptively
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
distance <- compute_sequence_distance(sequences)
fit <- cluster_sequences(distance, k = 2L)
validate_sequence_clusters(fit)

}
