% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-covariate-hmm.R
\name{summarise_covariate_sequence_hmm}
\alias{summarise_covariate_sequence_hmm}
\title{Summarise a covariate-dependent HMM}
\usage{
summarise_covariate_sequence_hmm(model)
}
\arguments{
\item{model}{A fitted covariate HMM.}
}
\value{
A list of fit, coefficient, and emission summaries.
}
\description{
Summarise a covariate-dependent HMM
}
\examples{
# See `fit_covariate_sequence_hmm()`.
}
