% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-visualisations-extended.R
\name{plot_sequence_cluster_silhouette}
\alias{plot_sequence_cluster_silhouette}
\title{Plot sequence-cluster silhouette values}
\usage{
plot_sequence_cluster_silhouette(clustering, distance = NULL, ...)
}
\arguments{
\item{clustering}{A clustering result or named assignment vector.}

\item{distance}{Optional distance when \code{clustering} is an assignment vector.}

\item{...}{Additional arguments passed to \code{\link[graphics:barplot]{graphics::barplot()}}.}
}
\value{
The ordered per-sequence silhouette table, invisibly.
}
\description{
Plot sequence-cluster silhouette values
}
\examples{
data <- data.frame(sequence_id = rep(paste0("s", 1:4), each = 4L),
                   sequence_order = rep(1:4, 4L),
                   state = c("A", "B", "C", "D", "A", "B", "C", "C",
                             "D", "C", "B", "A", "D", "C", "A", "A"))
distance <- compute_sequence_distance(data)
plot_sequence_cluster_silhouette(cluster_sequences(distance, 2L))
}
