% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-time-models.R
\name{summarise_time_varying_sequence_model}
\alias{summarise_time_varying_sequence_model}
\title{Summarise a time-varying sequence model}
\usage{
summarise_time_varying_sequence_model(model)
}
\arguments{
\item{model}{A fitted time-varying sequence model.}
}
\value{
A list containing model metadata, parametric terms, smooth terms,
deviance explained, and convergence information.
}
\description{
Summarise a time-varying sequence model
}
\examples{
# See `fit_time_varying_sequence_model()`.
}
