% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence-adapters.R
\name{as_seqhmm_sequences}
\alias{as_seqhmm_sequences}
\title{Convert sequence data to seqHMM observations}
\usage{
as_seqhmm_sequences(
  data,
  sequence_id_col = "sequence_id",
  order_col = "sequence_order",
  state_col = "state",
  ...
)
}
\arguments{
\item{data}{Long-format sequence data.}

\item{sequence_id_col, order_col, state_col}{Sequence columns.}

\item{...}{Additional arguments passed to \code{\link[=as_traminer_sequences]{as_traminer_sequences()}}.}
}
\value{
A TraMineR \code{stslist} suitable for \code{seqHMM::build_hmm()}.
}
\description{
Convert sequence data to seqHMM observations
}
\examples{
sequences <- data.frame(
  sequence_id = rep(c("s1", "s2", "s3", "s4"), each = 4L),
  sequence_order = rep(1:4, times = 4L),
  state = c("A", "B", "C", "D", "A", "B", "C", "C",
            "D", "C", "B", "A", "D", "C", "A", "A"),
  group = rep(c("g1", "g2"), each = 8L),
  stringsAsFactors = FALSE
)
if (requireNamespace("TraMineR", quietly = TRUE) &&
    requireNamespace("seqHMM", quietly = TRUE)) {
  as_seqhmm_sequences(sequences)
}

}
